package com.srs.comprehensive.mapper;

import com.srs.comprehensive.domain.CphStuEvaTask;

import java.util.List;

/**
 * 综合评价评定小组任务Mapper接口
 * 
 * @author srs
 * @date 2023-08-19
 */
public interface CphStuEvaTaskMapper 
{
    /**
     * 查询综合评价评定小组任务
     * 
     * @param id 综合评价评定小组任务主键
     * @return 综合评价评定小组任务
     */
    public CphStuEvaTask selectCphStuEvaTaskById(Long id);

    /**
     * 查询综合评价评定小组任务列表
     * 
     * @param cphStuEvaTask 综合评价评定小组任务
     * @return 综合评价评定小组任务集合
     */
    public List<CphStuEvaTask> selectCphStuEvaTaskList(CphStuEvaTask cphStuEvaTask);

    /**
     * 新增综合评价评定小组任务
     * 
     * @param cphStuEvaTask 综合评价评定小组任务
     * @return 结果
     */
    public int insertCphStuEvaTask(CphStuEvaTask cphStuEvaTask);

    /**
     * 修改综合评价评定小组任务
     * 
     * @param cphStuEvaTask 综合评价评定小组任务
     * @return 结果
     */
    public int updateCphStuEvaTask(CphStuEvaTask cphStuEvaTask);

    /**
     * 删除综合评价评定小组任务
     * 
     * @param id 综合评价评定小组任务主键
     * @return 结果
     */
    public int deleteCphStuEvaTaskById(Long id);

    /**
     * 批量删除综合评价评定小组任务
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCphStuEvaTaskByIds(Long[] ids);
}
